% Report template 
% Author
% 2019-12-19

### plot_1

![](./temp/figure_0.pdf){ height=80%% }

### plot_2

![](./temp/figure_1.pdf){ height=80%% }

### plot_3

![](./temp/figure_2.pdf){ height=80%% }

